"""Inquisitor constants."""
from enum import Enum, unique
from typing import Any

from .models import Error

LOGGER_SERVICE = "Verification"
LOGGER_SERVICE_HANDLE = "verificat"  # sevice handle can be at most 9 characters long

OAUTH_COOKIE = "access_token"


@unique
class Scope(str, Enum):
    """Authentication scope."""

    READ = "read"
    WRITE = "write"


@unique
class VerificationMethod(str, Enum):
    """Verification method."""

    LETTER = "letter"
    MOJEID = "mojeid"


@unique
class LogEntryType(str, Enum):
    """Enum with log entry types."""

    LOGIN = "Login"
    RESEND_MESSAGE = "ResendMessage"
    USE_METHOD = "UseMethod"
    VERIFY_CONTACT_DATA = "VerifyContactData"


@unique
class LoggerResult(str, Enum):
    """Enum with log entry results."""

    SUCCESS = "Success"
    FAIL = "Fail"
    ERROR = "Error"


@unique
class LogReferenceType(str, Enum):
    """Log reference type."""

    VERIFICATION = "verification"
    CONTACT = "contact"


COMMON_RESPONSES: dict[int | str, dict[str, Any]] = {
    401: {"description": "Unauthorized", "model": Error}
}


@unique
class EventType(str, Enum):
    """Verification event type."""

    SEND_MESSAGE = "send_message"
    USE_METHOD = "use_method"


@unique
class MessageType(str, Enum):
    """Verification message type."""

    INITIAL = "verification_initial"
    CONFIRMATION_LETTER = "verification_confirmation_letter"
