from unittest import TestCase
from unittest.mock import Mock, call, patch

from fakeredis.aioredis import FakeRedis
from fastapi.testclient import TestClient
from grill import LoggerClient

from inquisitor.constants import (
    LOGGER_SERVICE,
    LOGGER_SERVICE_HANDLE,
    LogEntryType,
    LoggerResult,
    LogReferenceType,
)
from inquisitor.main import app
from inquisitor.settings import Settings

from .utils import ApiTestCase


class AppStartupTest(TestCase):
    @patch("inquisitor.main.get_cache", autospec=True)
    @patch("inquisitor.main.get_logger_client", autospec=True)
    @patch("inquisitor.main.get_settings", autospec=True)
    def test_app_startup(self, get_settings, get_logger_client, get_cache):
        get_settings.return_value = Settings()
        logger_client = Mock(spec=LoggerClient)
        get_logger_client.return_value = logger_client
        cache = Mock(wraps=FakeRedis())
        get_cache.return_value = cache

        # Using TestClient as context manager fires startup events
        with TestClient(app):
            pass

        get_settings.assert_called()
        self.assertEqual(
            logger_client.mock_calls,
            [
                call.register_service(LOGGER_SERVICE, handle=LOGGER_SERVICE_HANDLE),
                call.register_log_entry_types(LOGGER_SERVICE, log_entry_types=LogEntryType),
                call.register_results(LOGGER_SERVICE, results=LoggerResult),
                call.register_object_reference_types(reference_types=LogReferenceType),
            ],
        )
        self.assertEqual(cache.mock_calls, [call.ping()])


class HealthcheckTest(ApiTestCase):
    async def test_healthcheck(self):
        response = self.client.get("/healthcheck/")
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response.json(), True)
